# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: npctransport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='npctransport.proto',
  package='npctransport_proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12npctransport.proto\x12\x12npctransport_proto\"\xa0+\n\rConfiguration\x12\x43\n\rinteraction_k\x18\x03 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12G\n\x11interaction_range\x18\x04 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12@\n\nbackbone_k\x18\x05 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x46\n\x10time_step_factor\x18\x06 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12>\n\x08\x62ox_side\x18\x07 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12=\n\tbox_is_on\x18\x08 \x02(\x0b\x32*.npctransport_proto.Configuration.IntRange\x12\x44\n\x0eslab_thickness\x18\t \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x43\n\rtunnel_radius\x18\n \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12>\n\nslab_is_on\x18\x0b \x02(\x0b\x32*.npctransport_proto.Configuration.IntRange\x12;\n\x05slack\x18\x0c \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x18\n\x10number_of_trials\x18\r \x02(\x05\x12 \n\x18maximal_number_of_frames\x18\x0e \x02(\x01\x12>\n\x03\x66gs\x18\x0f \x03(\x0b\x32\x31.npctransport_proto.Configuration.FGConfiguration\x12\x46\n\x08\x66loaters\x18\x10 \x03(\x0b\x32\x34.npctransport_proto.Configuration.FloatConfiguration\x12J\n\tobstacles\x18\x1b \x03(\x0b\x32\x37.npctransport_proto.Configuration.ObstacleConfiguration\x12\x43\n\x0cinteractions\x18\x11 \x03(\x0b\x32-.npctransport_proto.Configuration.Interaction\x12\x18\n\x10\x64ump_interval_ns\x18\x12 \x02(\x01\x12G\n\x11nonspecific_range\x18\x13 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x43\n\rnonspecific_k\x18\x14 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x46\n\x10\x61ngular_D_factor\x18\x15 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x1e\n\x16statistics_interval_ns\x18\x16 \x02(\x01\x12G\n\x11\x65xcluded_volume_k\x18\x17 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x1a\n\x12simulation_time_ns\x18\x18 \x02(\x01\x12I\n\x13statistics_fraction\x18\x19 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12!\n\x19maximum_number_of_minutes\x18\x1a \x01(\x01\x12#\n\x18\x66g_anchor_inflate_factor\x18\x1c \x01(\x01:\x01\x31\x12(\n\x1d\x61re_floaters_on_one_slab_side\x18\x1d \x01(\x05:\x01\x30\x12K\n\x15time_step_wave_factor\x18\x1e \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x32\n\'is_exclude_floaters_from_slab_initially\x18\x1f \x01(\x05:\x01\x31\x12*\n\x1doutput_statistics_interval_ns\x18  \x01(\x01:\x03\x31\x30\x30\x12\x43\n\rtemperature_k\x18! \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12(\n\x1boutput_npctransport_version\x18\" \x01(\x01:\x03\x34.5\x12\x1c\n\x11is_xyz_hist_stats\x18# \x01(\x05:\x01\x30\x12\x45\n\x0ftunnel_radius_k\x18$ \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12K\n\x15pore_anchored_beads_k\x18% \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x1f\n\x14is_backbone_harmonic\x18& \x01(\x05:\x01\x30\x12\x45\n\x0f\x62\x61\x63kbone_tau_ns\x18\' \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x1a&\n\x03XYZ\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\t\n\x01z\x18\x03 \x02(\x01\x1a\x45\n\x08IntRange\x12\r\n\x05lower\x18\x01 \x02(\x05\x12\r\n\x05upper\x18\x02 \x01(\x05\x12\r\n\x05steps\x18\x03 \x01(\x05\x12\x0c\n\x04\x62\x61se\x18\x04 \x01(\x01\x1aG\n\nFloatRange\x12\r\n\x05lower\x18\x01 \x02(\x01\x12\r\n\x05upper\x18\x02 \x01(\x01\x12\r\n\x05steps\x18\x03 \x01(\x05\x12\x0c\n\x04\x62\x61se\x18\x04 \x01(\x01\x1a\xda\x08\n\x0f\x46GConfiguration\x12\x43\n\x0fnumber_of_beads\x18\x01 \x02(\x0b\x32*.npctransport_proto.Configuration.IntRange\x12:\n\x06number\x18\x02 \x02(\x0b\x32*.npctransport_proto.Configuration.IntRange\x12<\n\x06radius\x18\x03 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12@\n\x0cinteractions\x18\x04 \x02(\x0b\x32*.npctransport_proto.Configuration.IntRange\x12H\n\x12rest_length_factor\x18\x05 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12>\n\x08\x64_factor\x18\x06 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12J\n\x14interaction_k_factor\x18\x07 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12N\n\x18interaction_range_factor\x18\x08 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x41\n\x12\x61nchor_coordinates\x18\t \x03(\x0b\x32%.npctransport_proto.Configuration.XYZ\x12\x0c\n\x04type\x18\n \x01(\t\x12\x12\n\x07is_tamd\x18\x0b \x01(\x05:\x01\x30\x12I\n\x13tamd_T_factor_coeff\x18\x0c \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12H\n\x12tamd_T_factor_base\x18\r \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12I\n\x13tamd_F_factor_coeff\x18\x0e \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12H\n\x12tamd_F_factor_base\x18\x0f \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12<\n\x06tamd_K\x18\x10 \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12!\n\x16site_relative_distance\x18\x11 \x01(\x01:\x01\x31\x12\x16\n\x0bsite_radius\x18\x12 \x01(\x01:\x01\x30\x12\x18\n\x10type_suffix_list\x18\x13 \x03(\t\x1a\xb2\x06\n\x12\x46loatConfiguration\x12:\n\x06number\x18\x01 \x02(\x0b\x32*.npctransport_proto.Configuration.IntRange\x12<\n\x06radius\x18\x02 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12@\n\x0cinteractions\x18\x03 \x02(\x0b\x32*.npctransport_proto.Configuration.IntRange\x12>\n\x08\x64_factor\x18\x04 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12J\n\x14interaction_k_factor\x18\x07 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12N\n\x18interaction_range_factor\x18\x08 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x0c\n\x04type\x18\t \x01(\t\x12>\n\x08k_z_bias\x18\n \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12G\n\x11k_z_bias_fraction\x18\x0b \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12!\n\x16site_relative_distance\x18\x0c \x01(\x01:\x01\x31\x12\x16\n\x0bsite_radius\x18\r \x01(\x01:\x01\x30\x12\x17\n\x0c\x62\x65\x61\x64s_tail_n\x18\x0e \x01(\x05:\x01\x30\x12\x1c\n\x11\x62\x65\x61\x64s_tail_radius\x18\x0f \x01(\x01:\x01\x30\x12\x17\n\x0c\x62\x65\x61\x64s_tail_k\x18\x10 \x01(\x01:\x01\x31\x12!\n\x16\x62\x65\x61\x64s_tail_bond_length\x18\x11 \x01(\x01:\x01\x31\x12?\n\x10site_coordinates\x18\x12 \x03(\x0b\x32%.npctransport_proto.Configuration.XYZ\x1a\xcc\x03\n\x15ObstacleConfiguration\x12\x33\n\x04xyzs\x18\x01 \x03(\x0b\x32%.npctransport_proto.Configuration.XYZ\x12<\n\x06radius\x18\x02 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12@\n\x0cinteractions\x18\x03 \x02(\x0b\x32*.npctransport_proto.Configuration.IntRange\x12\x14\n\tis_static\x18\x04 \x02(\x05:\x01\x31\x12>\n\x08\x64_factor\x18\x05 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12J\n\x14interaction_k_factor\x18\x06 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12N\n\x18interaction_range_factor\x18\x07 \x02(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x0c\n\x04type\x18\x08 \x02(\t\x1a\x99\x06\n\x0bInteraction\x12\r\n\x05type0\x18\x01 \x02(\t\x12\r\n\x05type1\x18\x02 \x02(\t\x12\x39\n\x05is_on\x18\x03 \x02(\x0b\x32*.npctransport_proto.Configuration.IntRange\x12\x43\n\rinteraction_k\x18\x04 \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12G\n\x11interaction_range\x18\x05 \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x44\n\x0ek_tangent_skew\x18\x06 \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12H\n\x12range_tangent_skew\x18\x07 \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x46\n\x10range_sigma0_deg\x18\x08 \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x46\n\x10range_sigma1_deg\x18\t \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12G\n\x11nonspecific_range\x18\n \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x43\n\rnonspecific_k\x18\x0b \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12G\n\x11\x65xcluded_volume_k\x18\x0c \x01(\x0b\x32,.npctransport_proto.Configuration.FloatRange\x12\x15\n\ractive_sites0\x18\r \x03(\x05\x12\x15\n\ractive_sites1\x18\x0e \x03(\x05\"\xf8-\n\nAssignment\x12\x11\n\twork_unit\x18\x01 \x02(\x05\x12\x45\n\rinteraction_k\x18\x03 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12I\n\x11interaction_range\x18\x04 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x42\n\nbackbone_k\x18\x05 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12H\n\x10time_step_factor\x18\x06 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12@\n\x08\x62ox_side\x18\x07 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12?\n\tbox_is_on\x18\x08 \x02(\x0b\x32,.npctransport_proto.Assignment.IntAssignment\x12\x46\n\x0eslab_thickness\x18\t \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x45\n\rtunnel_radius\x18\n \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12@\n\nslab_is_on\x18\x0b \x02(\x0b\x32,.npctransport_proto.Assignment.IntAssignment\x12=\n\x05slack\x18\x0c \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x18\n\x10number_of_trials\x18\r \x02(\x05\x12 \n\x18maximal_number_of_frames\x18\x0e \x02(\x01\x12\x38\n\x03\x66gs\x18\x0f \x03(\x0b\x32+.npctransport_proto.Assignment.FGAssignment\x12\x42\n\x08\x66loaters\x18\x10 \x03(\x0b\x32\x30.npctransport_proto.Assignment.FloaterAssignment\x12\x44\n\tobstacles\x18! \x03(\x0b\x32\x31.npctransport_proto.Assignment.ObstacleAssignment\x12J\n\x0cinteractions\x18\x11 \x03(\x0b\x32\x34.npctransport_proto.Assignment.InteractionAssignment\x12\x18\n\x10\x64ump_interval_ns\x18\x12 \x02(\x01\x12I\n\x11nonspecific_range\x18\x13 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x45\n\rnonspecific_k\x18\x14 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12H\n\x10\x61ngular_D_factor\x18\x15 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x1e\n\x16statistics_interval_ns\x18\x16 \x02(\x01\x12I\n\x11\x65xcluded_volume_k\x18\x17 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x18\n\x10number_of_frames\x18\x18 \x02(\x05\x12\x11\n\ttime_step\x18\x19 \x02(\x01\x12\r\n\x05range\x18\x1a \x02(\x01\x12\x1a\n\x12simulation_time_ns\x18\x1b \x02(\x01\x12\"\n\x1astatistics_interval_frames\x18\x1c \x02(\x01\x12\x1c\n\x14\x64ump_interval_frames\x18\x1d \x02(\x01\x12K\n\x13statistics_fraction\x18\x1e \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12!\n\x19maximum_number_of_minutes\x18\x1f \x01(\x01\x12\x13\n\x0brandom_seed\x18  \x01(\x04\x12#\n\x18\x66g_anchor_inflate_factor\x18\" \x01(\x01:\x01\x31\x12(\n\x1d\x61re_floaters_on_one_slab_side\x18# \x01(\x05:\x01\x30\x12M\n\x15time_step_wave_factor\x18$ \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x32\n\'is_exclude_floaters_from_slab_initially\x18% \x01(\x05:\x01\x31\x12\x1a\n\x12imp_module_version\x18& \x03(\t\x12\x1a\n\x12npc_module_version\x18\' \x03(\t\x12*\n\x1doutput_statistics_interval_ns\x18( \x01(\x01:\x03\x31\x30\x30\x12\x31\n!output_statistics_interval_frames\x18) \x01(\x05:\x06\x31\x30\x30\x30\x30\x30\x12\x45\n\rtemperature_k\x18* \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12#\n\x1boutput_npctransport_version\x18+ \x01(\x01\x12\x1c\n\x11is_xyz_hist_stats\x18, \x01(\x05:\x01\x30\x12G\n\x0ftunnel_radius_k\x18- \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12M\n\x15pore_anchored_beads_k\x18. \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x1f\n\x14is_backbone_harmonic\x18/ \x01(\x05:\x01\x31\x12G\n\x0f\x62\x61\x63kbone_tau_ns\x18\x30 \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x1a&\n\x03XYZ\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\t\n\x01z\x18\x03 \x02(\x01\x1a-\n\rIntAssignment\x12\r\n\x05value\x18\x01 \x02(\x05\x12\r\n\x05index\x18\x02 \x01(\x05\x1a/\n\x0f\x46loatAssignment\x12\r\n\x05value\x18\x01 \x02(\x01\x12\r\n\x05index\x18\x02 \x01(\x05\x1a\x8c\t\n\x0c\x46GAssignment\x12\x45\n\x0fnumber_of_beads\x18\x01 \x02(\x0b\x32,.npctransport_proto.Assignment.IntAssignment\x12<\n\x06number\x18\x02 \x02(\x0b\x32,.npctransport_proto.Assignment.IntAssignment\x12>\n\x06radius\x18\x03 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x42\n\x0cinteractions\x18\x04 \x02(\x0b\x32,.npctransport_proto.Assignment.IntAssignment\x12J\n\x12rest_length_factor\x18\x05 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12@\n\x08\x64_factor\x18\x06 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12L\n\x14interaction_k_factor\x18\x07 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12P\n\x18interaction_range_factor\x18\x08 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12>\n\x12\x61nchor_coordinates\x18\t \x03(\x0b\x32\".npctransport_proto.Assignment.XYZ\x12\x0c\n\x04type\x18\n \x01(\t\x12\x12\n\x07is_tamd\x18\x0b \x01(\x05:\x01\x30\x12K\n\x13tamd_T_factor_coeff\x18\x0c \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12J\n\x12tamd_T_factor_base\x18\r \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12K\n\x13tamd_F_factor_coeff\x18\x0e \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12J\n\x12tamd_F_factor_base\x18\x0f \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12>\n\x06tamd_K\x18\x10 \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12!\n\x16site_relative_distance\x18\x11 \x01(\x01:\x01\x31\x12\x16\n\x0bsite_radius\x18\x12 \x01(\x01:\x01\x30\x12\x18\n\x10type_suffix_list\x18\x13 \x03(\t\x12\x1c\n\x11\x62\x61\x63kbone_k_factor\x18\x14 \x01(\x01:\x01\x31\x1a\xbe\x06\n\x11\x46loaterAssignment\x12<\n\x06number\x18\x01 \x02(\x0b\x32,.npctransport_proto.Assignment.IntAssignment\x12>\n\x06radius\x18\x02 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x42\n\x0cinteractions\x18\x03 \x02(\x0b\x32,.npctransport_proto.Assignment.IntAssignment\x12@\n\x08\x64_factor\x18\x04 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12L\n\x14interaction_k_factor\x18\x05 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12P\n\x18interaction_range_factor\x18\x07 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x0c\n\x04type\x18\x08 \x01(\t\x12@\n\x08k_z_bias\x18\t \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12I\n\x11k_z_bias_fraction\x18\x0b \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12!\n\x16site_relative_distance\x18\x0c \x01(\x01:\x01\x31\x12\x16\n\x0bsite_radius\x18\r \x01(\x01:\x01\x30\x12\x17\n\x0c\x62\x65\x61\x64s_tail_n\x18\x0e \x01(\x05:\x01\x30\x12\x1c\n\x11\x62\x65\x61\x64s_tail_radius\x18\x0f \x01(\x01:\x01\x30\x12\x17\n\x0c\x62\x65\x61\x64s_tail_k\x18\x10 \x01(\x01:\x01\x31\x12!\n\x16\x62\x65\x61\x64s_tail_bond_length\x18\x11 \x01(\x01:\x01\x31\x12<\n\x10site_coordinates\x18\x12 \x03(\x0b\x32\".npctransport_proto.Assignment.XYZ\x1a\xd0\x03\n\x12ObstacleAssignment\x12\x30\n\x04xyzs\x18\x01 \x03(\x0b\x32\".npctransport_proto.Assignment.XYZ\x12>\n\x06radius\x18\x02 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x42\n\x0cinteractions\x18\x03 \x02(\x0b\x32,.npctransport_proto.Assignment.IntAssignment\x12\x14\n\tis_static\x18\x04 \x02(\x05:\x01\x31\x12@\n\x08\x64_factor\x18\x05 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12L\n\x14interaction_k_factor\x18\x06 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12P\n\x18interaction_range_factor\x18\x07 \x02(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x0c\n\x04type\x18\x08 \x02(\t\x1a\xb7\x06\n\x15InteractionAssignment\x12\r\n\x05type0\x18\x01 \x02(\t\x12\r\n\x05type1\x18\x02 \x02(\t\x12;\n\x05is_on\x18\x03 \x02(\x0b\x32,.npctransport_proto.Assignment.IntAssignment\x12\x45\n\rinteraction_k\x18\x04 \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12I\n\x11interaction_range\x18\x05 \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x46\n\x0ek_tangent_skew\x18\x06 \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12J\n\x12range_tangent_skew\x18\x07 \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12H\n\x10range_sigma0_deg\x18\x08 \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12H\n\x10range_sigma1_deg\x18\t \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12I\n\x11nonspecific_range\x18\n \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x45\n\rnonspecific_k\x18\x0b \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12I\n\x11\x65xcluded_volume_k\x18\x0c \x01(\x0b\x32..npctransport_proto.Assignment.FloatAssignment\x12\x15\n\ractive_sites0\x18\r \x03(\x05\x12\x15\n\ractive_sites1\x18\x0e \x03(\x05\"\xab\x1c\n\nStatistics\x12\x33\n\x03\x66gs\x18\x01 \x03(\x0b\x32&.npctransport_proto.Statistics.FGStats\x12;\n\x08\x66loaters\x18\x02 \x03(\x0b\x32).npctransport_proto.Statistics.FloatStats\x12\x1e\n\x13\x65nergy_per_particle\x18\x03 \x01(\x01:\x01\x30\x12\x1b\n\x10number_of_frames\x18\x04 \x01(\x05:\x01\x30\x12 \n\x15seconds_per_iteration\x18\x05 \x01(\x01:\x01\x30\x12\x45\n\x0cinteractions\x18\x06 \x03(\x0b\x32/.npctransport_proto.Statistics.InteractionStats\x12\x16\n\x0binterrupted\x18\x07 \x01(\x05:\x01\x30\x12 \n\x15\x62\x64_simulation_time_ns\x18\x08 \x01(\x01:\x01\x30\x12M\n\x13global_order_params\x18\t \x03(\x0b\x32\x30.npctransport_proto.Statistics.GlobalOrderParams\x12<\n\x08\x66g_beads\x18\n \x03(\x0b\x32*.npctransport_proto.Statistics.FGBeadStats\x1a\x14\n\x04Ints\x12\x0c\n\x04ints\x18\x01 \x03(\x05\x1a\x43\n\tInts_list\x12\x36\n\tints_list\x18\x01 \x03(\x0b\x32#.npctransport_proto.Statistics.Ints\x1aJ\n\nInts_lists\x12<\n\nints_lists\x18\x01 \x03(\x0b\x32(.npctransport_proto.Statistics.Ints_list\x1a\xca\x02\n\rFGOrderParams\x12\x0f\n\x07time_ns\x18\x01 \x02(\x01\x12\x0e\n\x06volume\x18\x02 \x02(\x01\x12\x1f\n\x17mean_radius_of_gyration\x18\x03 \x01(\x01\x12&\n\x1emean_square_radius_of_gyration\x18\x05 \x01(\x01\x12 \n\x18mean_end_to_end_distance\x18\x04 \x01(\x01\x12\'\n\x1fmean_square_end_to_end_distance\x18\x06 \x01(\x01\x12\x1d\n\x15\x66raction_chains_bound\x18\x07 \x01(\x01\x12&\n\x1e\x66loaters_per_interacting_chain\x18\x08 \x01(\x01\x12\x1a\n\x12mean_bond_distance\x18\t \x01(\x01\x12!\n\x19mean_square_bond_distance\x18\n \x01(\x01\x1a\x90\x02\n\x12\x46loaterOrderParams\x12\x0f\n\x07time_ns\x18\x01 \x02(\x01\x12%\n\x1dsite_interactions_per_floater\x18\x02 \x02(\x01\x12\x1c\n\x14interacting_fraction\x18\t \x01(\x02\x12%\n\x1d\x62\x65\x61\x64s_per_interacting_floater\x18\x03 \x02(\x01\x12&\n\x1e\x63hains_per_interacting_floater\x18\x04 \x02(\x01\x12\x0c\n\x04n_z0\x18\x05 \x01(\x05\x12\x0c\n\x04n_z1\x18\x06 \x01(\x05\x12\x0c\n\x04n_z2\x18\x07 \x01(\x05\x12\x0c\n\x04n_z3\x18\x08 \x01(\x05\x12\x1d\n\x15\x64iffusion_coefficient\x18\n \x01(\x02\x1a\xdc\x03\n\x07\x46GStats\x12\x11\n\x06volume\x18\x01 \x01(\x01:\x01\x30\x12\x11\n\x06length\x18\x02 \x01(\x01:\x01\x30\x12\x1d\n\x12radius_of_gyration\x18\x03 \x01(\x01:\x01\x30\x12)\n\x1eparticle_diffusion_coefficient\x18\x04 \x01(\x01:\x01\x30\x12$\n\x19particle_correlation_time\x18\x05 \x01(\x01:\x01\x30\x12&\n\x1b\x63hain_diffusion_coefficient\x18\x06 \x01(\x01:\x01\x30\x12!\n\x16\x63hain_correlation_time\x18\x07 \x01(\x01:\x01\x30\x12&\n\x1blocal_diffusion_coefficient\x18\x08 \x01(\x01:\x01\x30\x12\x0c\n\x04type\x18\t \x01(\t\x12\x42\n\x0corder_params\x18\n \x03(\x0b\x32,.npctransport_proto.Statistics.FGOrderParams\x12\x39\n\x07zr_hist\x18\x0b \x01(\x0b\x32(.npctransport_proto.Statistics.Ints_list\x12;\n\x08xyz_hist\x18\x0c \x01(\x0b\x32).npctransport_proto.Statistics.Ints_lists\x1a\xe4\x01\n\x0b\x46GBeadStats\x12)\n\x1eparticle_diffusion_coefficient\x18\x01 \x01(\x01:\x01\x30\x12$\n\x19particle_correlation_time\x18\x02 \x01(\x01:\x01\x30\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x39\n\x07zr_hist\x18\x04 \x01(\x0b\x32(.npctransport_proto.Statistics.Ints_list\x12;\n\x08xyz_hist\x18\x05 \x01(\x0b\x32).npctransport_proto.Statistics.Ints_lists\x1a\xd9\x02\n\nFloatStats\x12 \n\x15\x64iffusion_coefficient\x18\x05 \x01(\x01:\x01\x30\x12\x1b\n\x10\x63orrelation_time\x18\x06 \x01(\x01:\x01\x30\x12\x1b\n\x10\x61vg_n_transports\x18\x07 \x01(\x01:\x01\x30\x12 \n\x18transport_time_points_ns\x18\x08 \x03(\x01\x12\x0c\n\x04type\x18\t \x01(\t\x12G\n\x0corder_params\x18\n \x03(\x0b\x32\x31.npctransport_proto.Statistics.FloaterOrderParams\x12\x39\n\x07zr_hist\x18\x0b \x01(\x0b\x32(.npctransport_proto.Statistics.Ints_list\x12;\n\x08xyz_hist\x18\x0c \x01(\x0b\x32).npctransport_proto.Statistics.Ints_lists\x1a\x9b\x07\n\x16InteractionOrderParams\x12\x0f\n\x07time_ns\x18\x01 \x02(\x02\x12\"\n\x1a\x61vg_off_per_contact_per_ns\x18\x02 \x01(\x02\x12\"\n\x1a\x61vg_off_per_bound_i_per_ns\x18\x03 \x01(\x02\x12#\n\x1b\x61vg_off_per_bound_ii_per_ns\x18\x04 \x01(\x02\x12\x1b\n\x13off_stats_period_ns\x18\x05 \x01(\x02\x12)\n!avg_on_per_missing_contact_per_ns\x18\x06 \x01(\x02\x12\x1a\n\x12on_stats_period_ns\x18\x07 \x01(\x02\x12#\n\x1b\x61vg_on_per_unbound_i_per_ns\x18\x08 \x01(\x02\x12\x1c\n\x14on_i_stats_period_ns\x18\t \x01(\x02\x12$\n\x1c\x61vg_on_per_unbound_ii_per_ns\x18\n \x01(\x02\x12\x1d\n\x15on_ii_stats_period_ns\x18\x0b \x01(\x02\x12#\n\x1b\x61vg_contacts_per_particle_i\x18\x0c \x01(\x02\x12$\n\x1c\x61vg_contacts_per_particle_ii\x18\r \x01(\x02\x12&\n\x1e\x61vg_fraction_bound_particles_i\x18\x0e \x01(\x02\x12\'\n\x1f\x61vg_fraction_bound_particles_ii\x18\x0f \x01(\x02\x12\x1c\n\x14misc_stats_period_ns\x18\x10 \x01(\x02\x12\x1d\n\x15off_i_stats_period_ns\x18\x11 \x01(\x02\x12\x1e\n\x16off_ii_stats_period_ns\x18\x12 \x01(\x02\x12:\n2on_per_unbound_chain_i_per_unbound_chain_ii_per_ns\x18\x13 \x01(\x02\x12$\n\x1coff_per_bound_pair_of_chains\x18\x14 \x01(\x02\x12+\n#avg_fraction_bound_particle_sites_i\x18\x15 \x01(\x02\x12,\n$avg_fraction_bound_particle_sites_ii\x18\x16 \x01(\x02\x12/\n\'avg_fraction_nonspecific_interactions_i\x18\x17 \x01(\x02\x12\x30\n(avg_fraction_nonspecific_interactions_ii\x18\x18 \x01(\x02\x1a\x89\x02\n\x10InteractionStats\x12\r\n\x05type0\x18\x01 \x02(\t\x12\r\n\x05type1\x18\x02 \x02(\t\x12\"\n\x1a\x61vg_contacts_per_particle0\x18\x03 \x01(\x01\x12\"\n\x1a\x61vg_contacts_per_particle1\x18\x04 \x01(\x01\x12 \n\x18\x61vg_pct_bound_particles0\x18\x05 \x01(\x01\x12 \n\x18\x61vg_pct_bound_particles1\x18\x06 \x01(\x01\x12K\n\x0corder_params\x18\x07 \x03(\x0b\x32\x35.npctransport_proto.Statistics.InteractionOrderParams\x1ak\n\x11GlobalOrderParams\x12\x0f\n\x07time_ns\x18\x01 \x02(\x01\x12\x0e\n\x06\x65nergy\x18\x02 \x02(\x01\x12\x35\n\x08zr_hists\x18\x03 \x03(\x0b\x32#.npctransport_proto.Statistics.Ints\"\xe5\x02\n\x0c\x43onformation\x12\x35\n\x05sites\x18\x01 \x03(\x0b\x32&.npctransport_proto.Conformation.Sites\x12;\n\x08particle\x18\x02 \x03(\x0b\x32).npctransport_proto.Conformation.Particle\x1a.\n\x0b\x43oordinates\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\t\n\x01z\x18\x03 \x02(\x01\x1aX\n\x05Sites\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x41\n\x0b\x63oordinates\x18\x02 \x03(\x0b\x32,.npctransport_proto.Conformation.Coordinates\x1aW\n\x08Particle\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\t\n\x01z\x18\x03 \x02(\x01\x12\t\n\x01r\x18\x04 \x02(\x01\x12\t\n\x01i\x18\x05 \x02(\x01\x12\t\n\x01j\x18\x06 \x02(\x01\x12\t\n\x01k\x18\x07 \x02(\x01\"\xc2\x01\n\x06Output\x12\x32\n\nassignment\x18\x01 \x02(\x0b\x32\x1e.npctransport_proto.Assignment\x12\x32\n\nstatistics\x18\x02 \x02(\x0b\x32\x1e.npctransport_proto.Statistics\x12\x36\n\x0c\x63onformation\x18\x03 \x01(\x0b\x32 .npctransport_proto.Conformation\x12\x18\n\x10rmf_conformation\x18\x04 \x01(\x0c'
)




_CONFIGURATION_XYZ = _descriptor.Descriptor(
  name='XYZ',
  full_name='npctransport_proto.Configuration.XYZ',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='npctransport_proto.Configuration.XYZ.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='npctransport_proto.Configuration.XYZ.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='npctransport_proto.Configuration.XYZ.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2200,
  serialized_end=2238,
)

_CONFIGURATION_INTRANGE = _descriptor.Descriptor(
  name='IntRange',
  full_name='npctransport_proto.Configuration.IntRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lower', full_name='npctransport_proto.Configuration.IntRange.lower', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper', full_name='npctransport_proto.Configuration.IntRange.upper', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steps', full_name='npctransport_proto.Configuration.IntRange.steps', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='npctransport_proto.Configuration.IntRange.base', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2240,
  serialized_end=2309,
)

_CONFIGURATION_FLOATRANGE = _descriptor.Descriptor(
  name='FloatRange',
  full_name='npctransport_proto.Configuration.FloatRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lower', full_name='npctransport_proto.Configuration.FloatRange.lower', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper', full_name='npctransport_proto.Configuration.FloatRange.upper', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steps', full_name='npctransport_proto.Configuration.FloatRange.steps', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='npctransport_proto.Configuration.FloatRange.base', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2311,
  serialized_end=2382,
)

_CONFIGURATION_FGCONFIGURATION = _descriptor.Descriptor(
  name='FGConfiguration',
  full_name='npctransport_proto.Configuration.FGConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_of_beads', full_name='npctransport_proto.Configuration.FGConfiguration.number_of_beads', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='npctransport_proto.Configuration.FGConfiguration.number', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='npctransport_proto.Configuration.FGConfiguration.radius', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='npctransport_proto.Configuration.FGConfiguration.interactions', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rest_length_factor', full_name='npctransport_proto.Configuration.FGConfiguration.rest_length_factor', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_factor', full_name='npctransport_proto.Configuration.FGConfiguration.d_factor', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_k_factor', full_name='npctransport_proto.Configuration.FGConfiguration.interaction_k_factor', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range_factor', full_name='npctransport_proto.Configuration.FGConfiguration.interaction_range_factor', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anchor_coordinates', full_name='npctransport_proto.Configuration.FGConfiguration.anchor_coordinates', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='npctransport_proto.Configuration.FGConfiguration.type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_tamd', full_name='npctransport_proto.Configuration.FGConfiguration.is_tamd', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_T_factor_coeff', full_name='npctransport_proto.Configuration.FGConfiguration.tamd_T_factor_coeff', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_T_factor_base', full_name='npctransport_proto.Configuration.FGConfiguration.tamd_T_factor_base', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_F_factor_coeff', full_name='npctransport_proto.Configuration.FGConfiguration.tamd_F_factor_coeff', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_F_factor_base', full_name='npctransport_proto.Configuration.FGConfiguration.tamd_F_factor_base', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_K', full_name='npctransport_proto.Configuration.FGConfiguration.tamd_K', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_relative_distance', full_name='npctransport_proto.Configuration.FGConfiguration.site_relative_distance', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_radius', full_name='npctransport_proto.Configuration.FGConfiguration.site_radius', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_suffix_list', full_name='npctransport_proto.Configuration.FGConfiguration.type_suffix_list', index=18,
      number=19, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2385,
  serialized_end=3499,
)

_CONFIGURATION_FLOATCONFIGURATION = _descriptor.Descriptor(
  name='FloatConfiguration',
  full_name='npctransport_proto.Configuration.FloatConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='number', full_name='npctransport_proto.Configuration.FloatConfiguration.number', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='npctransport_proto.Configuration.FloatConfiguration.radius', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='npctransport_proto.Configuration.FloatConfiguration.interactions', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_factor', full_name='npctransport_proto.Configuration.FloatConfiguration.d_factor', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_k_factor', full_name='npctransport_proto.Configuration.FloatConfiguration.interaction_k_factor', index=4,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range_factor', full_name='npctransport_proto.Configuration.FloatConfiguration.interaction_range_factor', index=5,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='npctransport_proto.Configuration.FloatConfiguration.type', index=6,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k_z_bias', full_name='npctransport_proto.Configuration.FloatConfiguration.k_z_bias', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k_z_bias_fraction', full_name='npctransport_proto.Configuration.FloatConfiguration.k_z_bias_fraction', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_relative_distance', full_name='npctransport_proto.Configuration.FloatConfiguration.site_relative_distance', index=9,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_radius', full_name='npctransport_proto.Configuration.FloatConfiguration.site_radius', index=10,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beads_tail_n', full_name='npctransport_proto.Configuration.FloatConfiguration.beads_tail_n', index=11,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beads_tail_radius', full_name='npctransport_proto.Configuration.FloatConfiguration.beads_tail_radius', index=12,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beads_tail_k', full_name='npctransport_proto.Configuration.FloatConfiguration.beads_tail_k', index=13,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beads_tail_bond_length', full_name='npctransport_proto.Configuration.FloatConfiguration.beads_tail_bond_length', index=14,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_coordinates', full_name='npctransport_proto.Configuration.FloatConfiguration.site_coordinates', index=15,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3502,
  serialized_end=4320,
)

_CONFIGURATION_OBSTACLECONFIGURATION = _descriptor.Descriptor(
  name='ObstacleConfiguration',
  full_name='npctransport_proto.Configuration.ObstacleConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='xyzs', full_name='npctransport_proto.Configuration.ObstacleConfiguration.xyzs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='npctransport_proto.Configuration.ObstacleConfiguration.radius', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='npctransport_proto.Configuration.ObstacleConfiguration.interactions', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_static', full_name='npctransport_proto.Configuration.ObstacleConfiguration.is_static', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_factor', full_name='npctransport_proto.Configuration.ObstacleConfiguration.d_factor', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_k_factor', full_name='npctransport_proto.Configuration.ObstacleConfiguration.interaction_k_factor', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range_factor', full_name='npctransport_proto.Configuration.ObstacleConfiguration.interaction_range_factor', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='npctransport_proto.Configuration.ObstacleConfiguration.type', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4323,
  serialized_end=4783,
)

_CONFIGURATION_INTERACTION = _descriptor.Descriptor(
  name='Interaction',
  full_name='npctransport_proto.Configuration.Interaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type0', full_name='npctransport_proto.Configuration.Interaction.type0', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type1', full_name='npctransport_proto.Configuration.Interaction.type1', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_on', full_name='npctransport_proto.Configuration.Interaction.is_on', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_k', full_name='npctransport_proto.Configuration.Interaction.interaction_k', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range', full_name='npctransport_proto.Configuration.Interaction.interaction_range', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k_tangent_skew', full_name='npctransport_proto.Configuration.Interaction.k_tangent_skew', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_tangent_skew', full_name='npctransport_proto.Configuration.Interaction.range_tangent_skew', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_sigma0_deg', full_name='npctransport_proto.Configuration.Interaction.range_sigma0_deg', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_sigma1_deg', full_name='npctransport_proto.Configuration.Interaction.range_sigma1_deg', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonspecific_range', full_name='npctransport_proto.Configuration.Interaction.nonspecific_range', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonspecific_k', full_name='npctransport_proto.Configuration.Interaction.nonspecific_k', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_volume_k', full_name='npctransport_proto.Configuration.Interaction.excluded_volume_k', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_sites0', full_name='npctransport_proto.Configuration.Interaction.active_sites0', index=12,
      number=13, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_sites1', full_name='npctransport_proto.Configuration.Interaction.active_sites1', index=13,
      number=14, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4786,
  serialized_end=5579,
)

_CONFIGURATION = _descriptor.Descriptor(
  name='Configuration',
  full_name='npctransport_proto.Configuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interaction_k', full_name='npctransport_proto.Configuration.interaction_k', index=0,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range', full_name='npctransport_proto.Configuration.interaction_range', index=1,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backbone_k', full_name='npctransport_proto.Configuration.backbone_k', index=2,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_step_factor', full_name='npctransport_proto.Configuration.time_step_factor', index=3,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box_side', full_name='npctransport_proto.Configuration.box_side', index=4,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box_is_on', full_name='npctransport_proto.Configuration.box_is_on', index=5,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slab_thickness', full_name='npctransport_proto.Configuration.slab_thickness', index=6,
      number=9, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tunnel_radius', full_name='npctransport_proto.Configuration.tunnel_radius', index=7,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slab_is_on', full_name='npctransport_proto.Configuration.slab_is_on', index=8,
      number=11, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slack', full_name='npctransport_proto.Configuration.slack', index=9,
      number=12, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_trials', full_name='npctransport_proto.Configuration.number_of_trials', index=10,
      number=13, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximal_number_of_frames', full_name='npctransport_proto.Configuration.maximal_number_of_frames', index=11,
      number=14, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fgs', full_name='npctransport_proto.Configuration.fgs', index=12,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='floaters', full_name='npctransport_proto.Configuration.floaters', index=13,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacles', full_name='npctransport_proto.Configuration.obstacles', index=14,
      number=27, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='npctransport_proto.Configuration.interactions', index=15,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dump_interval_ns', full_name='npctransport_proto.Configuration.dump_interval_ns', index=16,
      number=18, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonspecific_range', full_name='npctransport_proto.Configuration.nonspecific_range', index=17,
      number=19, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonspecific_k', full_name='npctransport_proto.Configuration.nonspecific_k', index=18,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_D_factor', full_name='npctransport_proto.Configuration.angular_D_factor', index=19,
      number=21, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics_interval_ns', full_name='npctransport_proto.Configuration.statistics_interval_ns', index=20,
      number=22, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_volume_k', full_name='npctransport_proto.Configuration.excluded_volume_k', index=21,
      number=23, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulation_time_ns', full_name='npctransport_proto.Configuration.simulation_time_ns', index=22,
      number=24, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics_fraction', full_name='npctransport_proto.Configuration.statistics_fraction', index=23,
      number=25, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_number_of_minutes', full_name='npctransport_proto.Configuration.maximum_number_of_minutes', index=24,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fg_anchor_inflate_factor', full_name='npctransport_proto.Configuration.fg_anchor_inflate_factor', index=25,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='are_floaters_on_one_slab_side', full_name='npctransport_proto.Configuration.are_floaters_on_one_slab_side', index=26,
      number=29, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_step_wave_factor', full_name='npctransport_proto.Configuration.time_step_wave_factor', index=27,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_exclude_floaters_from_slab_initially', full_name='npctransport_proto.Configuration.is_exclude_floaters_from_slab_initially', index=28,
      number=31, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_statistics_interval_ns', full_name='npctransport_proto.Configuration.output_statistics_interval_ns', index=29,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperature_k', full_name='npctransport_proto.Configuration.temperature_k', index=30,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_npctransport_version', full_name='npctransport_proto.Configuration.output_npctransport_version', index=31,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(4.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_xyz_hist_stats', full_name='npctransport_proto.Configuration.is_xyz_hist_stats', index=32,
      number=35, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tunnel_radius_k', full_name='npctransport_proto.Configuration.tunnel_radius_k', index=33,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pore_anchored_beads_k', full_name='npctransport_proto.Configuration.pore_anchored_beads_k', index=34,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_backbone_harmonic', full_name='npctransport_proto.Configuration.is_backbone_harmonic', index=35,
      number=38, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backbone_tau_ns', full_name='npctransport_proto.Configuration.backbone_tau_ns', index=36,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONFIGURATION_XYZ, _CONFIGURATION_INTRANGE, _CONFIGURATION_FLOATRANGE, _CONFIGURATION_FGCONFIGURATION, _CONFIGURATION_FLOATCONFIGURATION, _CONFIGURATION_OBSTACLECONFIGURATION, _CONFIGURATION_INTERACTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=5579,
)


_ASSIGNMENT_XYZ = _descriptor.Descriptor(
  name='XYZ',
  full_name='npctransport_proto.Assignment.XYZ',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='npctransport_proto.Assignment.XYZ.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='npctransport_proto.Assignment.XYZ.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='npctransport_proto.Assignment.XYZ.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2200,
  serialized_end=2238,
)

_ASSIGNMENT_INTASSIGNMENT = _descriptor.Descriptor(
  name='IntAssignment',
  full_name='npctransport_proto.Assignment.IntAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='npctransport_proto.Assignment.IntAssignment.value', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='npctransport_proto.Assignment.IntAssignment.index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8075,
  serialized_end=8120,
)

_ASSIGNMENT_FLOATASSIGNMENT = _descriptor.Descriptor(
  name='FloatAssignment',
  full_name='npctransport_proto.Assignment.FloatAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='npctransport_proto.Assignment.FloatAssignment.value', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='npctransport_proto.Assignment.FloatAssignment.index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8122,
  serialized_end=8169,
)

_ASSIGNMENT_FGASSIGNMENT = _descriptor.Descriptor(
  name='FGAssignment',
  full_name='npctransport_proto.Assignment.FGAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_of_beads', full_name='npctransport_proto.Assignment.FGAssignment.number_of_beads', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='npctransport_proto.Assignment.FGAssignment.number', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='npctransport_proto.Assignment.FGAssignment.radius', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='npctransport_proto.Assignment.FGAssignment.interactions', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rest_length_factor', full_name='npctransport_proto.Assignment.FGAssignment.rest_length_factor', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_factor', full_name='npctransport_proto.Assignment.FGAssignment.d_factor', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_k_factor', full_name='npctransport_proto.Assignment.FGAssignment.interaction_k_factor', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range_factor', full_name='npctransport_proto.Assignment.FGAssignment.interaction_range_factor', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anchor_coordinates', full_name='npctransport_proto.Assignment.FGAssignment.anchor_coordinates', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='npctransport_proto.Assignment.FGAssignment.type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_tamd', full_name='npctransport_proto.Assignment.FGAssignment.is_tamd', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_T_factor_coeff', full_name='npctransport_proto.Assignment.FGAssignment.tamd_T_factor_coeff', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_T_factor_base', full_name='npctransport_proto.Assignment.FGAssignment.tamd_T_factor_base', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_F_factor_coeff', full_name='npctransport_proto.Assignment.FGAssignment.tamd_F_factor_coeff', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_F_factor_base', full_name='npctransport_proto.Assignment.FGAssignment.tamd_F_factor_base', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tamd_K', full_name='npctransport_proto.Assignment.FGAssignment.tamd_K', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_relative_distance', full_name='npctransport_proto.Assignment.FGAssignment.site_relative_distance', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_radius', full_name='npctransport_proto.Assignment.FGAssignment.site_radius', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_suffix_list', full_name='npctransport_proto.Assignment.FGAssignment.type_suffix_list', index=18,
      number=19, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backbone_k_factor', full_name='npctransport_proto.Assignment.FGAssignment.backbone_k_factor', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8172,
  serialized_end=9336,
)

_ASSIGNMENT_FLOATERASSIGNMENT = _descriptor.Descriptor(
  name='FloaterAssignment',
  full_name='npctransport_proto.Assignment.FloaterAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='number', full_name='npctransport_proto.Assignment.FloaterAssignment.number', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='npctransport_proto.Assignment.FloaterAssignment.radius', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='npctransport_proto.Assignment.FloaterAssignment.interactions', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_factor', full_name='npctransport_proto.Assignment.FloaterAssignment.d_factor', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_k_factor', full_name='npctransport_proto.Assignment.FloaterAssignment.interaction_k_factor', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range_factor', full_name='npctransport_proto.Assignment.FloaterAssignment.interaction_range_factor', index=5,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='npctransport_proto.Assignment.FloaterAssignment.type', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k_z_bias', full_name='npctransport_proto.Assignment.FloaterAssignment.k_z_bias', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k_z_bias_fraction', full_name='npctransport_proto.Assignment.FloaterAssignment.k_z_bias_fraction', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_relative_distance', full_name='npctransport_proto.Assignment.FloaterAssignment.site_relative_distance', index=9,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_radius', full_name='npctransport_proto.Assignment.FloaterAssignment.site_radius', index=10,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beads_tail_n', full_name='npctransport_proto.Assignment.FloaterAssignment.beads_tail_n', index=11,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beads_tail_radius', full_name='npctransport_proto.Assignment.FloaterAssignment.beads_tail_radius', index=12,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beads_tail_k', full_name='npctransport_proto.Assignment.FloaterAssignment.beads_tail_k', index=13,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beads_tail_bond_length', full_name='npctransport_proto.Assignment.FloaterAssignment.beads_tail_bond_length', index=14,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_coordinates', full_name='npctransport_proto.Assignment.FloaterAssignment.site_coordinates', index=15,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9339,
  serialized_end=10169,
)

_ASSIGNMENT_OBSTACLEASSIGNMENT = _descriptor.Descriptor(
  name='ObstacleAssignment',
  full_name='npctransport_proto.Assignment.ObstacleAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='xyzs', full_name='npctransport_proto.Assignment.ObstacleAssignment.xyzs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='npctransport_proto.Assignment.ObstacleAssignment.radius', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='npctransport_proto.Assignment.ObstacleAssignment.interactions', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_static', full_name='npctransport_proto.Assignment.ObstacleAssignment.is_static', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d_factor', full_name='npctransport_proto.Assignment.ObstacleAssignment.d_factor', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_k_factor', full_name='npctransport_proto.Assignment.ObstacleAssignment.interaction_k_factor', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range_factor', full_name='npctransport_proto.Assignment.ObstacleAssignment.interaction_range_factor', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='npctransport_proto.Assignment.ObstacleAssignment.type', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10172,
  serialized_end=10636,
)

_ASSIGNMENT_INTERACTIONASSIGNMENT = _descriptor.Descriptor(
  name='InteractionAssignment',
  full_name='npctransport_proto.Assignment.InteractionAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type0', full_name='npctransport_proto.Assignment.InteractionAssignment.type0', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type1', full_name='npctransport_proto.Assignment.InteractionAssignment.type1', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_on', full_name='npctransport_proto.Assignment.InteractionAssignment.is_on', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_k', full_name='npctransport_proto.Assignment.InteractionAssignment.interaction_k', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range', full_name='npctransport_proto.Assignment.InteractionAssignment.interaction_range', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k_tangent_skew', full_name='npctransport_proto.Assignment.InteractionAssignment.k_tangent_skew', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_tangent_skew', full_name='npctransport_proto.Assignment.InteractionAssignment.range_tangent_skew', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_sigma0_deg', full_name='npctransport_proto.Assignment.InteractionAssignment.range_sigma0_deg', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_sigma1_deg', full_name='npctransport_proto.Assignment.InteractionAssignment.range_sigma1_deg', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonspecific_range', full_name='npctransport_proto.Assignment.InteractionAssignment.nonspecific_range', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonspecific_k', full_name='npctransport_proto.Assignment.InteractionAssignment.nonspecific_k', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_volume_k', full_name='npctransport_proto.Assignment.InteractionAssignment.excluded_volume_k', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_sites0', full_name='npctransport_proto.Assignment.InteractionAssignment.active_sites0', index=12,
      number=13, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_sites1', full_name='npctransport_proto.Assignment.InteractionAssignment.active_sites1', index=13,
      number=14, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10639,
  serialized_end=11462,
)

_ASSIGNMENT = _descriptor.Descriptor(
  name='Assignment',
  full_name='npctransport_proto.Assignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='work_unit', full_name='npctransport_proto.Assignment.work_unit', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_k', full_name='npctransport_proto.Assignment.interaction_k', index=1,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interaction_range', full_name='npctransport_proto.Assignment.interaction_range', index=2,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backbone_k', full_name='npctransport_proto.Assignment.backbone_k', index=3,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_step_factor', full_name='npctransport_proto.Assignment.time_step_factor', index=4,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box_side', full_name='npctransport_proto.Assignment.box_side', index=5,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box_is_on', full_name='npctransport_proto.Assignment.box_is_on', index=6,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slab_thickness', full_name='npctransport_proto.Assignment.slab_thickness', index=7,
      number=9, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tunnel_radius', full_name='npctransport_proto.Assignment.tunnel_radius', index=8,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slab_is_on', full_name='npctransport_proto.Assignment.slab_is_on', index=9,
      number=11, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slack', full_name='npctransport_proto.Assignment.slack', index=10,
      number=12, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_trials', full_name='npctransport_proto.Assignment.number_of_trials', index=11,
      number=13, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximal_number_of_frames', full_name='npctransport_proto.Assignment.maximal_number_of_frames', index=12,
      number=14, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fgs', full_name='npctransport_proto.Assignment.fgs', index=13,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='floaters', full_name='npctransport_proto.Assignment.floaters', index=14,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacles', full_name='npctransport_proto.Assignment.obstacles', index=15,
      number=33, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='npctransport_proto.Assignment.interactions', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dump_interval_ns', full_name='npctransport_proto.Assignment.dump_interval_ns', index=17,
      number=18, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonspecific_range', full_name='npctransport_proto.Assignment.nonspecific_range', index=18,
      number=19, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonspecific_k', full_name='npctransport_proto.Assignment.nonspecific_k', index=19,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_D_factor', full_name='npctransport_proto.Assignment.angular_D_factor', index=20,
      number=21, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics_interval_ns', full_name='npctransport_proto.Assignment.statistics_interval_ns', index=21,
      number=22, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_volume_k', full_name='npctransport_proto.Assignment.excluded_volume_k', index=22,
      number=23, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_frames', full_name='npctransport_proto.Assignment.number_of_frames', index=23,
      number=24, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_step', full_name='npctransport_proto.Assignment.time_step', index=24,
      number=25, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range', full_name='npctransport_proto.Assignment.range', index=25,
      number=26, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulation_time_ns', full_name='npctransport_proto.Assignment.simulation_time_ns', index=26,
      number=27, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics_interval_frames', full_name='npctransport_proto.Assignment.statistics_interval_frames', index=27,
      number=28, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dump_interval_frames', full_name='npctransport_proto.Assignment.dump_interval_frames', index=28,
      number=29, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics_fraction', full_name='npctransport_proto.Assignment.statistics_fraction', index=29,
      number=30, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_number_of_minutes', full_name='npctransport_proto.Assignment.maximum_number_of_minutes', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_seed', full_name='npctransport_proto.Assignment.random_seed', index=31,
      number=32, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fg_anchor_inflate_factor', full_name='npctransport_proto.Assignment.fg_anchor_inflate_factor', index=32,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='are_floaters_on_one_slab_side', full_name='npctransport_proto.Assignment.are_floaters_on_one_slab_side', index=33,
      number=35, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_step_wave_factor', full_name='npctransport_proto.Assignment.time_step_wave_factor', index=34,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_exclude_floaters_from_slab_initially', full_name='npctransport_proto.Assignment.is_exclude_floaters_from_slab_initially', index=35,
      number=37, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imp_module_version', full_name='npctransport_proto.Assignment.imp_module_version', index=36,
      number=38, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='npc_module_version', full_name='npctransport_proto.Assignment.npc_module_version', index=37,
      number=39, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_statistics_interval_ns', full_name='npctransport_proto.Assignment.output_statistics_interval_ns', index=38,
      number=40, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_statistics_interval_frames', full_name='npctransport_proto.Assignment.output_statistics_interval_frames', index=39,
      number=41, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=100000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperature_k', full_name='npctransport_proto.Assignment.temperature_k', index=40,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_npctransport_version', full_name='npctransport_proto.Assignment.output_npctransport_version', index=41,
      number=43, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_xyz_hist_stats', full_name='npctransport_proto.Assignment.is_xyz_hist_stats', index=42,
      number=44, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tunnel_radius_k', full_name='npctransport_proto.Assignment.tunnel_radius_k', index=43,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pore_anchored_beads_k', full_name='npctransport_proto.Assignment.pore_anchored_beads_k', index=44,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_backbone_harmonic', full_name='npctransport_proto.Assignment.is_backbone_harmonic', index=45,
      number=47, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backbone_tau_ns', full_name='npctransport_proto.Assignment.backbone_tau_ns', index=46,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ASSIGNMENT_XYZ, _ASSIGNMENT_INTASSIGNMENT, _ASSIGNMENT_FLOATASSIGNMENT, _ASSIGNMENT_FGASSIGNMENT, _ASSIGNMENT_FLOATERASSIGNMENT, _ASSIGNMENT_OBSTACLEASSIGNMENT, _ASSIGNMENT_INTERACTIONASSIGNMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5582,
  serialized_end=11462,
)


_STATISTICS_INTS = _descriptor.Descriptor(
  name='Ints',
  full_name='npctransport_proto.Statistics.Ints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ints', full_name='npctransport_proto.Statistics.Ints.ints', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11958,
  serialized_end=11978,
)

_STATISTICS_INTS_LIST = _descriptor.Descriptor(
  name='Ints_list',
  full_name='npctransport_proto.Statistics.Ints_list',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ints_list', full_name='npctransport_proto.Statistics.Ints_list.ints_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11980,
  serialized_end=12047,
)

_STATISTICS_INTS_LISTS = _descriptor.Descriptor(
  name='Ints_lists',
  full_name='npctransport_proto.Statistics.Ints_lists',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ints_lists', full_name='npctransport_proto.Statistics.Ints_lists.ints_lists', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12049,
  serialized_end=12123,
)

_STATISTICS_FGORDERPARAMS = _descriptor.Descriptor(
  name='FGOrderParams',
  full_name='npctransport_proto.Statistics.FGOrderParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_ns', full_name='npctransport_proto.Statistics.FGOrderParams.time_ns', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='npctransport_proto.Statistics.FGOrderParams.volume', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_radius_of_gyration', full_name='npctransport_proto.Statistics.FGOrderParams.mean_radius_of_gyration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_square_radius_of_gyration', full_name='npctransport_proto.Statistics.FGOrderParams.mean_square_radius_of_gyration', index=3,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_end_to_end_distance', full_name='npctransport_proto.Statistics.FGOrderParams.mean_end_to_end_distance', index=4,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_square_end_to_end_distance', full_name='npctransport_proto.Statistics.FGOrderParams.mean_square_end_to_end_distance', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fraction_chains_bound', full_name='npctransport_proto.Statistics.FGOrderParams.fraction_chains_bound', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='floaters_per_interacting_chain', full_name='npctransport_proto.Statistics.FGOrderParams.floaters_per_interacting_chain', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_bond_distance', full_name='npctransport_proto.Statistics.FGOrderParams.mean_bond_distance', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_square_bond_distance', full_name='npctransport_proto.Statistics.FGOrderParams.mean_square_bond_distance', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12126,
  serialized_end=12456,
)

_STATISTICS_FLOATERORDERPARAMS = _descriptor.Descriptor(
  name='FloaterOrderParams',
  full_name='npctransport_proto.Statistics.FloaterOrderParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_ns', full_name='npctransport_proto.Statistics.FloaterOrderParams.time_ns', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='site_interactions_per_floater', full_name='npctransport_proto.Statistics.FloaterOrderParams.site_interactions_per_floater', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interacting_fraction', full_name='npctransport_proto.Statistics.FloaterOrderParams.interacting_fraction', index=2,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beads_per_interacting_floater', full_name='npctransport_proto.Statistics.FloaterOrderParams.beads_per_interacting_floater', index=3,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chains_per_interacting_floater', full_name='npctransport_proto.Statistics.FloaterOrderParams.chains_per_interacting_floater', index=4,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n_z0', full_name='npctransport_proto.Statistics.FloaterOrderParams.n_z0', index=5,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n_z1', full_name='npctransport_proto.Statistics.FloaterOrderParams.n_z1', index=6,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n_z2', full_name='npctransport_proto.Statistics.FloaterOrderParams.n_z2', index=7,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n_z3', full_name='npctransport_proto.Statistics.FloaterOrderParams.n_z3', index=8,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diffusion_coefficient', full_name='npctransport_proto.Statistics.FloaterOrderParams.diffusion_coefficient', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12459,
  serialized_end=12731,
)

_STATISTICS_FGSTATS = _descriptor.Descriptor(
  name='FGStats',
  full_name='npctransport_proto.Statistics.FGStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volume', full_name='npctransport_proto.Statistics.FGStats.volume', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='npctransport_proto.Statistics.FGStats.length', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius_of_gyration', full_name='npctransport_proto.Statistics.FGStats.radius_of_gyration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='particle_diffusion_coefficient', full_name='npctransport_proto.Statistics.FGStats.particle_diffusion_coefficient', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='particle_correlation_time', full_name='npctransport_proto.Statistics.FGStats.particle_correlation_time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_diffusion_coefficient', full_name='npctransport_proto.Statistics.FGStats.chain_diffusion_coefficient', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_correlation_time', full_name='npctransport_proto.Statistics.FGStats.chain_correlation_time', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_diffusion_coefficient', full_name='npctransport_proto.Statistics.FGStats.local_diffusion_coefficient', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='npctransport_proto.Statistics.FGStats.type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_params', full_name='npctransport_proto.Statistics.FGStats.order_params', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zr_hist', full_name='npctransport_proto.Statistics.FGStats.zr_hist', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xyz_hist', full_name='npctransport_proto.Statistics.FGStats.xyz_hist', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12734,
  serialized_end=13210,
)

_STATISTICS_FGBEADSTATS = _descriptor.Descriptor(
  name='FGBeadStats',
  full_name='npctransport_proto.Statistics.FGBeadStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='particle_diffusion_coefficient', full_name='npctransport_proto.Statistics.FGBeadStats.particle_diffusion_coefficient', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='particle_correlation_time', full_name='npctransport_proto.Statistics.FGBeadStats.particle_correlation_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='npctransport_proto.Statistics.FGBeadStats.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zr_hist', full_name='npctransport_proto.Statistics.FGBeadStats.zr_hist', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xyz_hist', full_name='npctransport_proto.Statistics.FGBeadStats.xyz_hist', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13213,
  serialized_end=13441,
)

_STATISTICS_FLOATSTATS = _descriptor.Descriptor(
  name='FloatStats',
  full_name='npctransport_proto.Statistics.FloatStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='diffusion_coefficient', full_name='npctransport_proto.Statistics.FloatStats.diffusion_coefficient', index=0,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correlation_time', full_name='npctransport_proto.Statistics.FloatStats.correlation_time', index=1,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_n_transports', full_name='npctransport_proto.Statistics.FloatStats.avg_n_transports', index=2,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_time_points_ns', full_name='npctransport_proto.Statistics.FloatStats.transport_time_points_ns', index=3,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='npctransport_proto.Statistics.FloatStats.type', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_params', full_name='npctransport_proto.Statistics.FloatStats.order_params', index=5,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zr_hist', full_name='npctransport_proto.Statistics.FloatStats.zr_hist', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xyz_hist', full_name='npctransport_proto.Statistics.FloatStats.xyz_hist', index=7,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13444,
  serialized_end=13789,
)

_STATISTICS_INTERACTIONORDERPARAMS = _descriptor.Descriptor(
  name='InteractionOrderParams',
  full_name='npctransport_proto.Statistics.InteractionOrderParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.time_ns', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_off_per_contact_per_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_off_per_contact_per_ns', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_off_per_bound_i_per_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_off_per_bound_i_per_ns', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_off_per_bound_ii_per_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_off_per_bound_ii_per_ns', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='off_stats_period_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.off_stats_period_ns', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_on_per_missing_contact_per_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_on_per_missing_contact_per_ns', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_stats_period_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.on_stats_period_ns', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_on_per_unbound_i_per_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_on_per_unbound_i_per_ns', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_i_stats_period_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.on_i_stats_period_ns', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_on_per_unbound_ii_per_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_on_per_unbound_ii_per_ns', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_ii_stats_period_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.on_ii_stats_period_ns', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_contacts_per_particle_i', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_contacts_per_particle_i', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_contacts_per_particle_ii', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_contacts_per_particle_ii', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_fraction_bound_particles_i', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_fraction_bound_particles_i', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_fraction_bound_particles_ii', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_fraction_bound_particles_ii', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='misc_stats_period_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.misc_stats_period_ns', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='off_i_stats_period_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.off_i_stats_period_ns', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='off_ii_stats_period_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.off_ii_stats_period_ns', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_per_unbound_chain_i_per_unbound_chain_ii_per_ns', full_name='npctransport_proto.Statistics.InteractionOrderParams.on_per_unbound_chain_i_per_unbound_chain_ii_per_ns', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='off_per_bound_pair_of_chains', full_name='npctransport_proto.Statistics.InteractionOrderParams.off_per_bound_pair_of_chains', index=19,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_fraction_bound_particle_sites_i', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_fraction_bound_particle_sites_i', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_fraction_bound_particle_sites_ii', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_fraction_bound_particle_sites_ii', index=21,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_fraction_nonspecific_interactions_i', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_fraction_nonspecific_interactions_i', index=22,
      number=23, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_fraction_nonspecific_interactions_ii', full_name='npctransport_proto.Statistics.InteractionOrderParams.avg_fraction_nonspecific_interactions_ii', index=23,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13792,
  serialized_end=14715,
)

_STATISTICS_INTERACTIONSTATS = _descriptor.Descriptor(
  name='InteractionStats',
  full_name='npctransport_proto.Statistics.InteractionStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type0', full_name='npctransport_proto.Statistics.InteractionStats.type0', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type1', full_name='npctransport_proto.Statistics.InteractionStats.type1', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_contacts_per_particle0', full_name='npctransport_proto.Statistics.InteractionStats.avg_contacts_per_particle0', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_contacts_per_particle1', full_name='npctransport_proto.Statistics.InteractionStats.avg_contacts_per_particle1', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_pct_bound_particles0', full_name='npctransport_proto.Statistics.InteractionStats.avg_pct_bound_particles0', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg_pct_bound_particles1', full_name='npctransport_proto.Statistics.InteractionStats.avg_pct_bound_particles1', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_params', full_name='npctransport_proto.Statistics.InteractionStats.order_params', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14718,
  serialized_end=14983,
)

_STATISTICS_GLOBALORDERPARAMS = _descriptor.Descriptor(
  name='GlobalOrderParams',
  full_name='npctransport_proto.Statistics.GlobalOrderParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_ns', full_name='npctransport_proto.Statistics.GlobalOrderParams.time_ns', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='energy', full_name='npctransport_proto.Statistics.GlobalOrderParams.energy', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zr_hists', full_name='npctransport_proto.Statistics.GlobalOrderParams.zr_hists', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14985,
  serialized_end=15092,
)

_STATISTICS = _descriptor.Descriptor(
  name='Statistics',
  full_name='npctransport_proto.Statistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fgs', full_name='npctransport_proto.Statistics.fgs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='floaters', full_name='npctransport_proto.Statistics.floaters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='energy_per_particle', full_name='npctransport_proto.Statistics.energy_per_particle', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_frames', full_name='npctransport_proto.Statistics.number_of_frames', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seconds_per_iteration', full_name='npctransport_proto.Statistics.seconds_per_iteration', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactions', full_name='npctransport_proto.Statistics.interactions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interrupted', full_name='npctransport_proto.Statistics.interrupted', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bd_simulation_time_ns', full_name='npctransport_proto.Statistics.bd_simulation_time_ns', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_order_params', full_name='npctransport_proto.Statistics.global_order_params', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fg_beads', full_name='npctransport_proto.Statistics.fg_beads', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATISTICS_INTS, _STATISTICS_INTS_LIST, _STATISTICS_INTS_LISTS, _STATISTICS_FGORDERPARAMS, _STATISTICS_FLOATERORDERPARAMS, _STATISTICS_FGSTATS, _STATISTICS_FGBEADSTATS, _STATISTICS_FLOATSTATS, _STATISTICS_INTERACTIONORDERPARAMS, _STATISTICS_INTERACTIONSTATS, _STATISTICS_GLOBALORDERPARAMS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11465,
  serialized_end=15092,
)


_CONFORMATION_COORDINATES = _descriptor.Descriptor(
  name='Coordinates',
  full_name='npctransport_proto.Conformation.Coordinates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='npctransport_proto.Conformation.Coordinates.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='npctransport_proto.Conformation.Coordinates.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='npctransport_proto.Conformation.Coordinates.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15227,
  serialized_end=15273,
)

_CONFORMATION_SITES = _descriptor.Descriptor(
  name='Sites',
  full_name='npctransport_proto.Conformation.Sites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='npctransport_proto.Conformation.Sites.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='npctransport_proto.Conformation.Sites.coordinates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15275,
  serialized_end=15363,
)

_CONFORMATION_PARTICLE = _descriptor.Descriptor(
  name='Particle',
  full_name='npctransport_proto.Conformation.Particle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='npctransport_proto.Conformation.Particle.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='npctransport_proto.Conformation.Particle.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='npctransport_proto.Conformation.Particle.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='r', full_name='npctransport_proto.Conformation.Particle.r', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i', full_name='npctransport_proto.Conformation.Particle.i', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='j', full_name='npctransport_proto.Conformation.Particle.j', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k', full_name='npctransport_proto.Conformation.Particle.k', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15365,
  serialized_end=15452,
)

_CONFORMATION = _descriptor.Descriptor(
  name='Conformation',
  full_name='npctransport_proto.Conformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sites', full_name='npctransport_proto.Conformation.sites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='particle', full_name='npctransport_proto.Conformation.particle', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONFORMATION_COORDINATES, _CONFORMATION_SITES, _CONFORMATION_PARTICLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15095,
  serialized_end=15452,
)


_OUTPUT = _descriptor.Descriptor(
  name='Output',
  full_name='npctransport_proto.Output',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assignment', full_name='npctransport_proto.Output.assignment', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='npctransport_proto.Output.statistics', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conformation', full_name='npctransport_proto.Output.conformation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rmf_conformation', full_name='npctransport_proto.Output.rmf_conformation', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15455,
  serialized_end=15649,
)

_CONFIGURATION_XYZ.containing_type = _CONFIGURATION
_CONFIGURATION_INTRANGE.containing_type = _CONFIGURATION
_CONFIGURATION_FLOATRANGE.containing_type = _CONFIGURATION
_CONFIGURATION_FGCONFIGURATION.fields_by_name['number_of_beads'].message_type = _CONFIGURATION_INTRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['number'].message_type = _CONFIGURATION_INTRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['radius'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['interactions'].message_type = _CONFIGURATION_INTRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['rest_length_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['d_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['interaction_k_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['interaction_range_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['anchor_coordinates'].message_type = _CONFIGURATION_XYZ
_CONFIGURATION_FGCONFIGURATION.fields_by_name['tamd_T_factor_coeff'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['tamd_T_factor_base'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['tamd_F_factor_coeff'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['tamd_F_factor_base'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.fields_by_name['tamd_K'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FGCONFIGURATION.containing_type = _CONFIGURATION
_CONFIGURATION_FLOATCONFIGURATION.fields_by_name['number'].message_type = _CONFIGURATION_INTRANGE
_CONFIGURATION_FLOATCONFIGURATION.fields_by_name['radius'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FLOATCONFIGURATION.fields_by_name['interactions'].message_type = _CONFIGURATION_INTRANGE
_CONFIGURATION_FLOATCONFIGURATION.fields_by_name['d_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FLOATCONFIGURATION.fields_by_name['interaction_k_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FLOATCONFIGURATION.fields_by_name['interaction_range_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FLOATCONFIGURATION.fields_by_name['k_z_bias'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FLOATCONFIGURATION.fields_by_name['k_z_bias_fraction'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_FLOATCONFIGURATION.fields_by_name['site_coordinates'].message_type = _CONFIGURATION_XYZ
_CONFIGURATION_FLOATCONFIGURATION.containing_type = _CONFIGURATION
_CONFIGURATION_OBSTACLECONFIGURATION.fields_by_name['xyzs'].message_type = _CONFIGURATION_XYZ
_CONFIGURATION_OBSTACLECONFIGURATION.fields_by_name['radius'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_OBSTACLECONFIGURATION.fields_by_name['interactions'].message_type = _CONFIGURATION_INTRANGE
_CONFIGURATION_OBSTACLECONFIGURATION.fields_by_name['d_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_OBSTACLECONFIGURATION.fields_by_name['interaction_k_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_OBSTACLECONFIGURATION.fields_by_name['interaction_range_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_OBSTACLECONFIGURATION.containing_type = _CONFIGURATION
_CONFIGURATION_INTERACTION.fields_by_name['is_on'].message_type = _CONFIGURATION_INTRANGE
_CONFIGURATION_INTERACTION.fields_by_name['interaction_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_INTERACTION.fields_by_name['interaction_range'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_INTERACTION.fields_by_name['k_tangent_skew'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_INTERACTION.fields_by_name['range_tangent_skew'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_INTERACTION.fields_by_name['range_sigma0_deg'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_INTERACTION.fields_by_name['range_sigma1_deg'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_INTERACTION.fields_by_name['nonspecific_range'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_INTERACTION.fields_by_name['nonspecific_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_INTERACTION.fields_by_name['excluded_volume_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION_INTERACTION.containing_type = _CONFIGURATION
_CONFIGURATION.fields_by_name['interaction_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['interaction_range'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['backbone_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['time_step_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['box_side'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['box_is_on'].message_type = _CONFIGURATION_INTRANGE
_CONFIGURATION.fields_by_name['slab_thickness'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['tunnel_radius'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['slab_is_on'].message_type = _CONFIGURATION_INTRANGE
_CONFIGURATION.fields_by_name['slack'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['fgs'].message_type = _CONFIGURATION_FGCONFIGURATION
_CONFIGURATION.fields_by_name['floaters'].message_type = _CONFIGURATION_FLOATCONFIGURATION
_CONFIGURATION.fields_by_name['obstacles'].message_type = _CONFIGURATION_OBSTACLECONFIGURATION
_CONFIGURATION.fields_by_name['interactions'].message_type = _CONFIGURATION_INTERACTION
_CONFIGURATION.fields_by_name['nonspecific_range'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['nonspecific_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['angular_D_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['excluded_volume_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['statistics_fraction'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['time_step_wave_factor'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['temperature_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['tunnel_radius_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['pore_anchored_beads_k'].message_type = _CONFIGURATION_FLOATRANGE
_CONFIGURATION.fields_by_name['backbone_tau_ns'].message_type = _CONFIGURATION_FLOATRANGE
_ASSIGNMENT_XYZ.containing_type = _ASSIGNMENT
_ASSIGNMENT_INTASSIGNMENT.containing_type = _ASSIGNMENT
_ASSIGNMENT_FLOATASSIGNMENT.containing_type = _ASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['number_of_beads'].message_type = _ASSIGNMENT_INTASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['number'].message_type = _ASSIGNMENT_INTASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['radius'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['interactions'].message_type = _ASSIGNMENT_INTASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['rest_length_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['d_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['interaction_k_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['interaction_range_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['anchor_coordinates'].message_type = _ASSIGNMENT_XYZ
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['tamd_T_factor_coeff'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['tamd_T_factor_base'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['tamd_F_factor_coeff'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['tamd_F_factor_base'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.fields_by_name['tamd_K'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FGASSIGNMENT.containing_type = _ASSIGNMENT
_ASSIGNMENT_FLOATERASSIGNMENT.fields_by_name['number'].message_type = _ASSIGNMENT_INTASSIGNMENT
_ASSIGNMENT_FLOATERASSIGNMENT.fields_by_name['radius'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FLOATERASSIGNMENT.fields_by_name['interactions'].message_type = _ASSIGNMENT_INTASSIGNMENT
_ASSIGNMENT_FLOATERASSIGNMENT.fields_by_name['d_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FLOATERASSIGNMENT.fields_by_name['interaction_k_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FLOATERASSIGNMENT.fields_by_name['interaction_range_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FLOATERASSIGNMENT.fields_by_name['k_z_bias'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FLOATERASSIGNMENT.fields_by_name['k_z_bias_fraction'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_FLOATERASSIGNMENT.fields_by_name['site_coordinates'].message_type = _ASSIGNMENT_XYZ
_ASSIGNMENT_FLOATERASSIGNMENT.containing_type = _ASSIGNMENT
_ASSIGNMENT_OBSTACLEASSIGNMENT.fields_by_name['xyzs'].message_type = _ASSIGNMENT_XYZ
_ASSIGNMENT_OBSTACLEASSIGNMENT.fields_by_name['radius'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_OBSTACLEASSIGNMENT.fields_by_name['interactions'].message_type = _ASSIGNMENT_INTASSIGNMENT
_ASSIGNMENT_OBSTACLEASSIGNMENT.fields_by_name['d_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_OBSTACLEASSIGNMENT.fields_by_name['interaction_k_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_OBSTACLEASSIGNMENT.fields_by_name['interaction_range_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_OBSTACLEASSIGNMENT.containing_type = _ASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['is_on'].message_type = _ASSIGNMENT_INTASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['interaction_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['interaction_range'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['k_tangent_skew'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['range_tangent_skew'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['range_sigma0_deg'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['range_sigma1_deg'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['nonspecific_range'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['nonspecific_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.fields_by_name['excluded_volume_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT_INTERACTIONASSIGNMENT.containing_type = _ASSIGNMENT
_ASSIGNMENT.fields_by_name['interaction_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['interaction_range'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['backbone_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['time_step_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['box_side'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['box_is_on'].message_type = _ASSIGNMENT_INTASSIGNMENT
_ASSIGNMENT.fields_by_name['slab_thickness'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['tunnel_radius'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['slab_is_on'].message_type = _ASSIGNMENT_INTASSIGNMENT
_ASSIGNMENT.fields_by_name['slack'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['fgs'].message_type = _ASSIGNMENT_FGASSIGNMENT
_ASSIGNMENT.fields_by_name['floaters'].message_type = _ASSIGNMENT_FLOATERASSIGNMENT
_ASSIGNMENT.fields_by_name['obstacles'].message_type = _ASSIGNMENT_OBSTACLEASSIGNMENT
_ASSIGNMENT.fields_by_name['interactions'].message_type = _ASSIGNMENT_INTERACTIONASSIGNMENT
_ASSIGNMENT.fields_by_name['nonspecific_range'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['nonspecific_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['angular_D_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['excluded_volume_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['statistics_fraction'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['time_step_wave_factor'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['temperature_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['tunnel_radius_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['pore_anchored_beads_k'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_ASSIGNMENT.fields_by_name['backbone_tau_ns'].message_type = _ASSIGNMENT_FLOATASSIGNMENT
_STATISTICS_INTS.containing_type = _STATISTICS
_STATISTICS_INTS_LIST.fields_by_name['ints_list'].message_type = _STATISTICS_INTS
_STATISTICS_INTS_LIST.containing_type = _STATISTICS
_STATISTICS_INTS_LISTS.fields_by_name['ints_lists'].message_type = _STATISTICS_INTS_LIST
_STATISTICS_INTS_LISTS.containing_type = _STATISTICS
_STATISTICS_FGORDERPARAMS.containing_type = _STATISTICS
_STATISTICS_FLOATERORDERPARAMS.containing_type = _STATISTICS
_STATISTICS_FGSTATS.fields_by_name['order_params'].message_type = _STATISTICS_FGORDERPARAMS
_STATISTICS_FGSTATS.fields_by_name['zr_hist'].message_type = _STATISTICS_INTS_LIST
_STATISTICS_FGSTATS.fields_by_name['xyz_hist'].message_type = _STATISTICS_INTS_LISTS
_STATISTICS_FGSTATS.containing_type = _STATISTICS
_STATISTICS_FGBEADSTATS.fields_by_name['zr_hist'].message_type = _STATISTICS_INTS_LIST
_STATISTICS_FGBEADSTATS.fields_by_name['xyz_hist'].message_type = _STATISTICS_INTS_LISTS
_STATISTICS_FGBEADSTATS.containing_type = _STATISTICS
_STATISTICS_FLOATSTATS.fields_by_name['order_params'].message_type = _STATISTICS_FLOATERORDERPARAMS
_STATISTICS_FLOATSTATS.fields_by_name['zr_hist'].message_type = _STATISTICS_INTS_LIST
_STATISTICS_FLOATSTATS.fields_by_name['xyz_hist'].message_type = _STATISTICS_INTS_LISTS
_STATISTICS_FLOATSTATS.containing_type = _STATISTICS
_STATISTICS_INTERACTIONORDERPARAMS.containing_type = _STATISTICS
_STATISTICS_INTERACTIONSTATS.fields_by_name['order_params'].message_type = _STATISTICS_INTERACTIONORDERPARAMS
_STATISTICS_INTERACTIONSTATS.containing_type = _STATISTICS
_STATISTICS_GLOBALORDERPARAMS.fields_by_name['zr_hists'].message_type = _STATISTICS_INTS
_STATISTICS_GLOBALORDERPARAMS.containing_type = _STATISTICS
_STATISTICS.fields_by_name['fgs'].message_type = _STATISTICS_FGSTATS
_STATISTICS.fields_by_name['floaters'].message_type = _STATISTICS_FLOATSTATS
_STATISTICS.fields_by_name['interactions'].message_type = _STATISTICS_INTERACTIONSTATS
_STATISTICS.fields_by_name['global_order_params'].message_type = _STATISTICS_GLOBALORDERPARAMS
_STATISTICS.fields_by_name['fg_beads'].message_type = _STATISTICS_FGBEADSTATS
_CONFORMATION_COORDINATES.containing_type = _CONFORMATION
_CONFORMATION_SITES.fields_by_name['coordinates'].message_type = _CONFORMATION_COORDINATES
_CONFORMATION_SITES.containing_type = _CONFORMATION
_CONFORMATION_PARTICLE.containing_type = _CONFORMATION
_CONFORMATION.fields_by_name['sites'].message_type = _CONFORMATION_SITES
_CONFORMATION.fields_by_name['particle'].message_type = _CONFORMATION_PARTICLE
_OUTPUT.fields_by_name['assignment'].message_type = _ASSIGNMENT
_OUTPUT.fields_by_name['statistics'].message_type = _STATISTICS
_OUTPUT.fields_by_name['conformation'].message_type = _CONFORMATION
DESCRIPTOR.message_types_by_name['Configuration'] = _CONFIGURATION
DESCRIPTOR.message_types_by_name['Assignment'] = _ASSIGNMENT
DESCRIPTOR.message_types_by_name['Statistics'] = _STATISTICS
DESCRIPTOR.message_types_by_name['Conformation'] = _CONFORMATION
DESCRIPTOR.message_types_by_name['Output'] = _OUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Configuration = _reflection.GeneratedProtocolMessageType('Configuration', (_message.Message,), {

  'XYZ' : _reflection.GeneratedProtocolMessageType('XYZ', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGURATION_XYZ,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Configuration.XYZ)
    })
  ,

  'IntRange' : _reflection.GeneratedProtocolMessageType('IntRange', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGURATION_INTRANGE,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Configuration.IntRange)
    })
  ,

  'FloatRange' : _reflection.GeneratedProtocolMessageType('FloatRange', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGURATION_FLOATRANGE,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Configuration.FloatRange)
    })
  ,

  'FGConfiguration' : _reflection.GeneratedProtocolMessageType('FGConfiguration', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGURATION_FGCONFIGURATION,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Configuration.FGConfiguration)
    })
  ,

  'FloatConfiguration' : _reflection.GeneratedProtocolMessageType('FloatConfiguration', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGURATION_FLOATCONFIGURATION,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Configuration.FloatConfiguration)
    })
  ,

  'ObstacleConfiguration' : _reflection.GeneratedProtocolMessageType('ObstacleConfiguration', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGURATION_OBSTACLECONFIGURATION,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Configuration.ObstacleConfiguration)
    })
  ,

  'Interaction' : _reflection.GeneratedProtocolMessageType('Interaction', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGURATION_INTERACTION,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Configuration.Interaction)
    })
  ,
  'DESCRIPTOR' : _CONFIGURATION,
  '__module__' : 'npctransport_pb2'
  # @@protoc_insertion_point(class_scope:npctransport_proto.Configuration)
  })
_sym_db.RegisterMessage(Configuration)
_sym_db.RegisterMessage(Configuration.XYZ)
_sym_db.RegisterMessage(Configuration.IntRange)
_sym_db.RegisterMessage(Configuration.FloatRange)
_sym_db.RegisterMessage(Configuration.FGConfiguration)
_sym_db.RegisterMessage(Configuration.FloatConfiguration)
_sym_db.RegisterMessage(Configuration.ObstacleConfiguration)
_sym_db.RegisterMessage(Configuration.Interaction)

Assignment = _reflection.GeneratedProtocolMessageType('Assignment', (_message.Message,), {

  'XYZ' : _reflection.GeneratedProtocolMessageType('XYZ', (_message.Message,), {
    'DESCRIPTOR' : _ASSIGNMENT_XYZ,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Assignment.XYZ)
    })
  ,

  'IntAssignment' : _reflection.GeneratedProtocolMessageType('IntAssignment', (_message.Message,), {
    'DESCRIPTOR' : _ASSIGNMENT_INTASSIGNMENT,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Assignment.IntAssignment)
    })
  ,

  'FloatAssignment' : _reflection.GeneratedProtocolMessageType('FloatAssignment', (_message.Message,), {
    'DESCRIPTOR' : _ASSIGNMENT_FLOATASSIGNMENT,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Assignment.FloatAssignment)
    })
  ,

  'FGAssignment' : _reflection.GeneratedProtocolMessageType('FGAssignment', (_message.Message,), {
    'DESCRIPTOR' : _ASSIGNMENT_FGASSIGNMENT,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Assignment.FGAssignment)
    })
  ,

  'FloaterAssignment' : _reflection.GeneratedProtocolMessageType('FloaterAssignment', (_message.Message,), {
    'DESCRIPTOR' : _ASSIGNMENT_FLOATERASSIGNMENT,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Assignment.FloaterAssignment)
    })
  ,

  'ObstacleAssignment' : _reflection.GeneratedProtocolMessageType('ObstacleAssignment', (_message.Message,), {
    'DESCRIPTOR' : _ASSIGNMENT_OBSTACLEASSIGNMENT,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Assignment.ObstacleAssignment)
    })
  ,

  'InteractionAssignment' : _reflection.GeneratedProtocolMessageType('InteractionAssignment', (_message.Message,), {
    'DESCRIPTOR' : _ASSIGNMENT_INTERACTIONASSIGNMENT,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Assignment.InteractionAssignment)
    })
  ,
  'DESCRIPTOR' : _ASSIGNMENT,
  '__module__' : 'npctransport_pb2'
  # @@protoc_insertion_point(class_scope:npctransport_proto.Assignment)
  })
_sym_db.RegisterMessage(Assignment)
_sym_db.RegisterMessage(Assignment.XYZ)
_sym_db.RegisterMessage(Assignment.IntAssignment)
_sym_db.RegisterMessage(Assignment.FloatAssignment)
_sym_db.RegisterMessage(Assignment.FGAssignment)
_sym_db.RegisterMessage(Assignment.FloaterAssignment)
_sym_db.RegisterMessage(Assignment.ObstacleAssignment)
_sym_db.RegisterMessage(Assignment.InteractionAssignment)

Statistics = _reflection.GeneratedProtocolMessageType('Statistics', (_message.Message,), {

  'Ints' : _reflection.GeneratedProtocolMessageType('Ints', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_INTS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.Ints)
    })
  ,

  'Ints_list' : _reflection.GeneratedProtocolMessageType('Ints_list', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_INTS_LIST,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.Ints_list)
    })
  ,

  'Ints_lists' : _reflection.GeneratedProtocolMessageType('Ints_lists', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_INTS_LISTS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.Ints_lists)
    })
  ,

  'FGOrderParams' : _reflection.GeneratedProtocolMessageType('FGOrderParams', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_FGORDERPARAMS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.FGOrderParams)
    })
  ,

  'FloaterOrderParams' : _reflection.GeneratedProtocolMessageType('FloaterOrderParams', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_FLOATERORDERPARAMS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.FloaterOrderParams)
    })
  ,

  'FGStats' : _reflection.GeneratedProtocolMessageType('FGStats', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_FGSTATS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.FGStats)
    })
  ,

  'FGBeadStats' : _reflection.GeneratedProtocolMessageType('FGBeadStats', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_FGBEADSTATS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.FGBeadStats)
    })
  ,

  'FloatStats' : _reflection.GeneratedProtocolMessageType('FloatStats', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_FLOATSTATS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.FloatStats)
    })
  ,

  'InteractionOrderParams' : _reflection.GeneratedProtocolMessageType('InteractionOrderParams', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_INTERACTIONORDERPARAMS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.InteractionOrderParams)
    })
  ,

  'InteractionStats' : _reflection.GeneratedProtocolMessageType('InteractionStats', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_INTERACTIONSTATS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.InteractionStats)
    })
  ,

  'GlobalOrderParams' : _reflection.GeneratedProtocolMessageType('GlobalOrderParams', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_GLOBALORDERPARAMS,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics.GlobalOrderParams)
    })
  ,
  'DESCRIPTOR' : _STATISTICS,
  '__module__' : 'npctransport_pb2'
  # @@protoc_insertion_point(class_scope:npctransport_proto.Statistics)
  })
_sym_db.RegisterMessage(Statistics)
_sym_db.RegisterMessage(Statistics.Ints)
_sym_db.RegisterMessage(Statistics.Ints_list)
_sym_db.RegisterMessage(Statistics.Ints_lists)
_sym_db.RegisterMessage(Statistics.FGOrderParams)
_sym_db.RegisterMessage(Statistics.FloaterOrderParams)
_sym_db.RegisterMessage(Statistics.FGStats)
_sym_db.RegisterMessage(Statistics.FGBeadStats)
_sym_db.RegisterMessage(Statistics.FloatStats)
_sym_db.RegisterMessage(Statistics.InteractionOrderParams)
_sym_db.RegisterMessage(Statistics.InteractionStats)
_sym_db.RegisterMessage(Statistics.GlobalOrderParams)

Conformation = _reflection.GeneratedProtocolMessageType('Conformation', (_message.Message,), {

  'Coordinates' : _reflection.GeneratedProtocolMessageType('Coordinates', (_message.Message,), {
    'DESCRIPTOR' : _CONFORMATION_COORDINATES,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Conformation.Coordinates)
    })
  ,

  'Sites' : _reflection.GeneratedProtocolMessageType('Sites', (_message.Message,), {
    'DESCRIPTOR' : _CONFORMATION_SITES,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Conformation.Sites)
    })
  ,

  'Particle' : _reflection.GeneratedProtocolMessageType('Particle', (_message.Message,), {
    'DESCRIPTOR' : _CONFORMATION_PARTICLE,
    '__module__' : 'npctransport_pb2'
    # @@protoc_insertion_point(class_scope:npctransport_proto.Conformation.Particle)
    })
  ,
  'DESCRIPTOR' : _CONFORMATION,
  '__module__' : 'npctransport_pb2'
  # @@protoc_insertion_point(class_scope:npctransport_proto.Conformation)
  })
_sym_db.RegisterMessage(Conformation)
_sym_db.RegisterMessage(Conformation.Coordinates)
_sym_db.RegisterMessage(Conformation.Sites)
_sym_db.RegisterMessage(Conformation.Particle)

Output = _reflection.GeneratedProtocolMessageType('Output', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUT,
  '__module__' : 'npctransport_pb2'
  # @@protoc_insertion_point(class_scope:npctransport_proto.Output)
  })
_sym_db.RegisterMessage(Output)


# @@protoc_insertion_point(module_scope)
